@@ -16,10 +16,9 @@ Brightfield
 """
 
 import numpy as np
-from deeptrack.features import Feature, StructuralFeature
-from deeptrack.image import Image, pad_image_to_fft
+from .features import Feature, StructuralFeature
+from .image import Image, pad_image_to_fft
 
-from scipy.interpolate import RectBivariateSpline
 from scipy.ndimage import convolve
 
 
@@ -78,7 +77,13 @@ class Microscope(StructuralFeature):
         if upscale > 1:
             mean_imaged_sample = np.reshape(
                 imaged_sample,
-                (shape[0] // upscale, upscale, shape[1] // upscale, upscale, shape[2]),
+                (
+                    shape[0] // upscale,
+                    upscale,
+                    shape[1] // upscale,
+                    upscale,
+                    shape[2],
+                ),
             ).mean(axis=(3, 1))
 
             imaged_sample = Image(mean_imaged_sample).merge_properties_from(
@@ -97,7 +102,10 @@ class Microscope(StructuralFeature):
 
     def _update(self, **kwargs):
         self.properties["sample"].update(
-            **{**kwargs, **self.objective.update(**kwargs).current_value.properties}
+            **{
+                **kwargs,
+                **self.objective.update(**kwargs).current_value.properties,
+            }
         )
         super()._update(**kwargs)
 
@@ -140,7 +148,7 @@ class Optics(Feature):
         self,
         NA=0.7,
         wavelength=0.66e-6,
-        magnification=1,
+        magnification=10,
         resolution=(1e-6, 1e-6, 1e-6),
         refractive_index_medium=1.33,
         upscale=1,
@@ -282,11 +290,15 @@ class Optics(Feature):
             new_limits[i, :] = (
                 np.min([new_limits[i, 0], upscaled_output_region[i] - padding[1]]),
                 np.max(
-                    [new_limits[i, 1], upscaled_output_region[i + 2] + padding[i + 2]]
+                    [
+                        new_limits[i, 1],
+                        upscaled_output_region[i + 2] + padding[i + 2],
+                    ]
                 ),
             )
         new_volume = np.zeros(
-            np.diff(new_limits, axis=1)[:, 0].astype(np.int32), dtype=np.complex
+            np.diff(new_limits, axis=1)[:, 0].astype(np.int32),
+            dtype=np.complex,
         )
 
         old_region = (limits - new_limits).astype(np.int32)
@@ -370,7 +382,9 @@ class Fluorescence(Optics):
         )
 
         padded_volume = padded_volume[
-            output_region[0] : output_region[2], output_region[1] : output_region[3], :
+            output_region[0] : output_region[2],
+            output_region[1] : output_region[3],
+            :,
         ]
         z_limits = limits[2, :]
 
@@ -380,7 +394,10 @@ class Fluorescence(Optics):
 
         # Get planes in volume where not all values are 0.
         z_iterator = np.linspace(
-            z_limits[0], z_limits[1], num=padded_volume.shape[2], endpoint=False
+            z_limits[0],
+            z_limits[1],
+            num=padded_volume.shape[2],
+            endpoint=False,
         )
         zero_plane = np.all(padded_volume == 0, axis=(0, 1), keepdims=False)
         z_values = z_iterator[~zero_plane]
@@ -496,7 +513,9 @@ class Brightfield(Optics):
         )
 
         padded_volume = padded_volume[
-            output_region[0] : output_region[2], output_region[1] : output_region[3], :
+            output_region[0] : output_region[2],
+            output_region[1] : output_region[3],
+            :,
         ]
         z_limits = limits[2, :]
 
@@ -504,7 +523,10 @@ class Brightfield(Optics):
 
         index_iterator = range(padded_volume.shape[2])
         z_iterator = np.linspace(
-            z_limits[0], z_limits[1], num=padded_volume.shape[2], endpoint=False
+            z_limits[0],
+            z_limits[1],
+            num=padded_volume.shape[2],
+            endpoint=False,
         )
 
         zero_plane = np.all(padded_volume == 0, axis=(0, 1), keepdims=False)
@@ -766,7 +788,12 @@ def _create_volume(
             continue
 
         padded_scatterer = Image(
-            np.pad(scatterer, [(2, 2), (2, 2), (2, 2)], "constant", constant_values=0)
+            np.pad(
+                scatterer,
+                [(2, 2), (2, 2), (2, 2)],
+                "constant",
+                constant_values=0,
+            )
         )
         padded_scatterer.properties = scatterer.properties
         scatterer = padded_scatterer
@@ -815,7 +842,8 @@ def _create_volume(
 
         if not (np.array(new_limits) == np.array(limits)).all():
             new_volume = np.zeros(
-                np.diff(new_limits, axis=1)[:, 0].astype(np.int32), dtype=np.complex
+                np.diff(new_limits, axis=1)[:, 0].astype(np.int32),
+                dtype=np.complex,
             )
             old_region = (limits - new_limits).astype(np.int32)
             limits = limits.astype(np.int32)
