@@ -1,6 +1,6 @@
 """Implementations of Feature the model scattering objects.
 
-Provides some basic implementations of scattering objects 
+Provides some basic implementations of scattering objects
 that are frequently used.
 
 Classes
@@ -18,14 +18,13 @@ Ellipsoid
 """
 
 
-from threading import Lock
 import numpy as np
 
-# from scipy.special import jv as jn, spherical_jn as jv, h1vp, eval_legendre as leg, jvp
-import deeptrack.backend as D
-from deeptrack.features import Feature, MERGE_STRATEGY_APPEND
-from deeptrack.image import Image
-import deeptrack.image
+from . import backend as D
+from .features import Feature, MERGE_STRATEGY_APPEND
+from .image import Image
+from . import image
+import warnings
 
 
 class Scatterer(Feature):
@@ -60,8 +59,8 @@ class Scatterer(Feature):
     Other Parameters
     ----------------
     upsample_axes : tuple of ints
-        Sets the axes along which the calculation is upsampled (default is None,
-        which implies all axes are upsampled).
+        Sets the axes along which the calculation is upsampled (default is
+        None, which implies all axes are upsampled).
     crop_zeros : bool
         Whether to remove slices in which all elements are zero.
     """
@@ -112,10 +111,11 @@ class Scatterer(Feature):
         # Post processes the created object to handle upsampling,
         # as well as cropping empty slices.
         if not self._processed_properties:
-            import warnings
 
             warnings.warn(
-                "Overridden _process_properties method does not call super. This is likely to result in errors if used with Optics.upscale != 1."
+                "Overridden _process_properties method does not call super. "
+                + "This is likely to result in errors if used with "
+                + "Optics.upscale != 1."
             )
 
         # Calculates upsampled voxel_size
@@ -134,7 +134,10 @@ class Scatterer(Feature):
 
         if new_image.size == 0:
             warnings.warn(
-                "Scatterer created that is smaller than a pixel. This may yield inconsistent results. Consider using upsample on the scatterer, or upscale on the optics.",
+                "Scatterer created that is smaller than a pixel. "
+                + "This may yield inconsistent results."
+                + " Consider using upsample on the scatterer,"
+                + " or upscale on the optics.",
                 Warning,
             )
 
@@ -346,7 +349,8 @@ class Ellipsoid(Scatterer):
         length 3.
 
         If the radius is a single value, the particle is made a sphere
-        If the radius are two values, the smallest value is appended as the third value
+        If the radius are two values, the smallest value is appended as the
+        third value
 
         The rotation vector is padded with zeros until it is of length 3
         """
@@ -426,12 +430,13 @@ class Ellipsoid(Scatterer):
 class MieScatterer(Scatterer):
     """Base implementation of a Mie particle.
 
-    New Mie-theory scatterers can be implemented by extending this class, and passing
-    a function that calculates the coefficients of the harmonics up to order `L`. To be
-    precise, the feature expects a wrapper function that takes the current values of the
-    properties, as well as a inner function that takes an integer as the only parameter,
-    and calculates the coefficients up to that integer. The return format is expected to
-    be a tuple with two values, corresponding to `an` and `bn`. See
+    New Mie-theory scatterers can be implemented by extending this class, and
+    passing a function that calculates the coefficients of the harmonics up to
+    order `L`. To beprecise, the feature expects a wrapper function that takes
+    the current values of the properties, as well as a inner function that
+    takes an integer as the only parameter, and calculates the coefficients up
+    to that integer. The return format is expected to be a tuple with two
+    values, corresponding to `an` and `bn`. See
     `deeptrack.backend.mie_coefficients` for an example.
 
     Parameters
@@ -439,11 +444,13 @@ class MieScatterer(Scatterer):
     coefficients : Callable[int] -> Tuple[ndarray, ndarray]
         Function that returns the harmonics coefficients.
     offset_z : "auto" or float
-        Distance from the particle in the z direction the field is evaluated. If "auto",
-        this is calculated from the pixel size and `collection_angle`
+        Distance from the particle in the z direction the field is evaluated.
+        If "auto", this is calculated from the pixel size and
+        `collection_angle`
     collection_angle : "auto" or float
         The maximum collection angle in radians. If "auto", this
-        is calculated from the objective NA (which is true if the objective is the limiting
+        is calculated from the objective NA (which is true if the objective is
+        the limiting
         aperature).
     polarization_angle : float
         Angle of the polarization of the incoming light relative to the x-axis.
@@ -507,7 +514,7 @@ class MieScatterer(Scatterer):
 
     def get(
         self,
-        image,
+        inp,
         position,
         upscaled_output_region,
         voxel_size,
@@ -535,7 +542,7 @@ class MieScatterer(Scatterer):
             - upscaled_output_region[1]
             + padding[1]
         )
-        arr = deeptrack.image.pad_image_to_fft(np.zeros((xSize, ySize)))
+        arr = image.pad_image_to_fft(np.zeros((xSize, ySize)))
 
         # Evluation grid
         x = np.arange(-padding[0], arr.shape[0] - padding[0]) - (position[1]) * upscale
@@ -561,11 +568,11 @@ class MieScatterer(Scatterer):
         PI, TAU = D.mie_harmonics(ct, L)
 
         # Normalization factor
-        E = [(2 * l + 1) / (l * (l + 1)) for l in range(1, L + 1)]
+        E = [(2 * i + 1) / (i * (i + 1)) for i in range(1, L + 1)]
 
         # Scattering terms
-        S1 = sum([E[l] * A[l] * TAU[l] + E[l] * B[l] * PI[l] for l in range(0, L)])
-        S2 = sum([E[l] * B[l] * TAU[l] + E[l] * A[l] * PI[l] for l in range(0, L)])
+        S1 = sum([E[i] * A[i] * TAU[i] + E[i] * B[i] * PI[i] for i in range(0, L)])
+        S2 = sum([E[i] * B[i] * TAU[i] + E[i] * A[i] * PI[i] for i in range(0, L)])
 
         field = (
             (ct > ct_max)
@@ -581,11 +588,13 @@ class MieScatterer(Scatterer):
 class MieSphere(MieScatterer):
     """Scattered field by a sphere
 
-    Should be calculated on at least a 64 by 64 grid. Use padding in the optics if necessary
+    Should be calculated on at least a 64 by 64 grid. Use padding in the
+    optics if necessary.
 
-    Calculates the scattered field by a spherical particle in a homogenous medium,
-    as predicted by Mie theory. Note that the induced phase shift is calculated
-    in comparison to the `refractive_index_medium` property of the optical device.
+    Calculates the scattered field by a spherical particle in a homogenous
+    medium, as predicted by Mie theory. Note that the induced phase shift is
+    calculated in comparison to the `refractive_index_medium` property of the
+    optical device.
 
     Parameters
     ----------
@@ -604,12 +613,13 @@ class MieSphere(MieScatterer):
         The position in the direction normal to the
         camera plane. Used if `position` is of length 2.
     offset_z : "auto" or float
-        Distance from the particle in the z direction the field is evaluated. If "auto",
-        this is calculated from the pixel size and `collection_angle`
+        Distance from the particle in the z direction the field is evaluated.
+        If "auto", this is calculated from the pixel size and
+        `collection_angle`
     collection_angle : "auto" or float
         The maximum collection angle in radians. If "auto", this
-        is calculated from the objective NA (which is true if the objective is the limiting
-        aperature).
+        is calculated from the objective NA (which is true if the objective
+        is the limiting aperature).
     polarization_angle : float
         Angle of the polarization of the incoming light relative to the x-axis.
     """
@@ -649,13 +659,15 @@ class MieSphere(MieScatterer):
 class MieStratifiedSphere(MieScatterer):
     """Scattered field by a stratified sphere
 
-    A stratified sphere is a sphere with several concentric shells of uniform refractive index.
+    A stratified sphere is a sphere with several concentric shells of uniform
+    refractive index.
 
-    Should be calculated on at least a 64 by 64 grid. Use padding in the optics if necessary
+    Should be calculated on at least a 64 by 64 grid. Use padding in the
+    optics if necessary
 
-    Calculates the scattered field by in a homogenous medium, as predicted by Mie theory.
-    Note that the induced phase shift is calculated in comparison to the
-    `refractive_index_medium` property of the optical device.
+    Calculates the scattered field by in a homogenous medium, as predicted by
+    Mie theory. Note that the induced phase shift is calculated in comparison
+    to the `refractive_index_medium` property of the optical device.
 
     Parameters
     ----------
@@ -674,12 +686,13 @@ class MieStratifiedSphere(MieScatterer):
         The position in the direction normal to the
         camera plane. Used if `position` is of length 2.
     offset_z : "auto" or float
-        Distance from the particle in the z direction the field is evaluated. If "auto",
-        this is calculated from the pixel size and `collection_angle`
+        Distance from the particle in the z direction the field is evaluated.
+        If "auto", this is calculated from the pixel size and
+        `collection_angle`
     collection_angle : "auto" or float
         The maximum collection angle in radians. If "auto", this
-        is calculated from the objective NA (which is true if the objective is the limiting
-        aperature).
+        is calculated from the objective NA (which is true if the objective
+        is the limiting aperature).
     polarization_angle : float
         Angle of the polarization of the incoming light relative to the x-axis.
     """
